==> appmate_flutter-0.0.1.tar.gz: example/lib/purchase.dart <==
import 'dart:developer';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:appmate_flutter_example/util.dart';
import 'package:flutter/services.dart';
import 'package:appmate_flutter/PurchaseClient.dart';
import 'package:appmate_flutter/models.dart';
import 'package:flutter/cupertino.dart';

class PurchaseList extends StatefulWidget {
  const PurchaseList({Key? key}) : super(key: key);

  @override
  _PurchaseListState createState() => _PurchaseListState();
}

class _PurchaseListState extends State<PurchaseList> {
  List<PurchaseInfo> _purchases = [];

  Object segmentedControlGroupValue = 0;
  final _biggerFont = const TextStyle(fontSize: 18);

  @override
  void initState() {
    super.initState();
    getCurrentPurchases();
  }

  Future<void> getCurrentPurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.getCurrentPurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    if (!mounted) return;

    setState(() {
      _purchases = purchases;
    });
  }

  Future<void> getAllPurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.getAllPurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    if (!mounted) return;

    setState(() {
      _purchases = purchases;
    });
  }

  Future<void> restorePurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.restorePurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    print("restorePurchases");
    print(purchases);

    if (!mounted) return;

    if (segmentedControlGroupValue == 0) {
      getCurrentPurchases();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      backgroundColor: Colors.grey[200],
      appBar: AppBar(
        title: Text('AppMate Example'),
        actions: <Widget>[
          IconButton(
            icon: Icon(
              Icons.restore,
              color: Colors.white,
            ),
            onPressed: () {
              restorePurchases();
            },
          )
        ],
        centerTitle: false,
        backgroundColor: Colors.redAccent,
      ),
      body: SingleChildScrollView(child: _buildPurchases()),
    );
  }

  Widget _buildPurchases() {
    return Column(
      children: [
        Padding(
          padding: const EdgeInsets.only(top: 16),
          child: CupertinoSlidingSegmentedControl(
              groupValue: segmentedControlGroupValue,
              children: {
                0: Text("Current Purchases"),
                1: Text("Purchase History")
              },
              onValueChanged: (i) {
                setState(() {
                  segmentedControlGroupValue = i!;
                  if (segmentedControlGroupValue == 0) {
                    getCurrentPurchases();
                  } else if (segmentedControlGroupValue == 1) {
                    getAllPurchases();
                  }
                });
              }),
        ),
        ListView.builder(
            itemCount: _purchases.length * 2,
            padding: const EdgeInsets.all(5),
            shrinkWrap: true,
            physics: NeverScrollableScrollPhysics(),
            itemBuilder: (BuildContext _context, int i) {
              if (i.isOdd) {
                return Divider();
              }
              final int index = i ~/ 2;
              if (index >= _purchases.length) {
                return Divider();
              }
              return _buildRow(_purchases[index]);
            })
      ],
    );
  }

  String getProductType(String purchaseType) {
    if (purchaseType == "0") {
      return "Consumable";
    } else if (purchaseType == "1") {
      return "Nonsoncumable";
    } else if (purchaseType == "2") {
      return "Subscription";
    }
    return "";
  }

  Widget _buildRow(PurchaseInfo p) {
    return ListTile(
      title: Text(
        "token : " + p.purchaseToken! +
        "\nprice : " + (double.parse(p.price!) / 100).toStringAsFixed(2) + ' ' + p.currency!,
        style: _biggerFont,
      ),
      subtitle: Text("productId        : " + p.productId! + 
                   "\npurchaseType : " + getProductType(p.purchaseType!) + 
                   "\norderId            : " + p.orderId! + 
                   "\npurchaseTime : " + p.purchaseTime! + 
                   "\nconsumed       : " + p.consumed!.toString()
                   ),
      trailing: getTrailingIcon(p),
      onTap: () {},
    );
  }

  Future<void> consumePurchase(PurchaseInfo p) async {
    BaseResponse response;
    try {
      response = await PurchaseClient.consumePurchase(p.purchaseToken!);
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        Util.showDialog(context, response.success ? "Consume Success" : "Unknown Error");
        getCurrentPurchases();
      }
    } on PlatformException {}

    if (!mounted) return;
  }

  Future<void> unsubscribe(PurchaseInfo p) async {
    BaseResponse response;
    try {
      response = await PurchaseClient.unsubscribe(p.purchaseToken!);
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        Util.showDialog(context, response.success ? "Unsubscribe Success" : "Unknown Error");
        getAllPurchases();
      }
    } on PlatformException {}

    if (!mounted) return;
  }

  Widget? getTrailingIcon(PurchaseInfo p) {
    if (segmentedControlGroupValue == 0 && p.purchaseType == "0") {
      return IconButton(
            icon: Icon(
              Icons.payment,
              color: Colors.redAccent,
            ),
            onPressed: () {
              consumePurchase(p);
            },
          );
    } else if (segmentedControlGroupValue == 1 && p.purchaseType == "2") {
      return IconButton(
            icon: Icon(
              Icons.cancel,
              color: Colors.redAccent,
            ),
            onPressed: () {
              unsubscribe(p);
            },
          );
    }
    return null;
  }
}

==> appmate_flutter-1.0.1.tar.gz: example/lib/purchase.dart <==
import 'dart:async';

import 'package:appmate_flutter/PurchaseClient.dart';
import 'package:appmate_flutter/helpers/BaseResponse.dart';
import 'package:appmate_flutter/helpers/PurchasesResponse.dart';
import 'package:appmate_flutter/models/PurchaseInfo.dart';
import 'package:appmate_flutter_example/util.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class PurchaseList extends StatefulWidget {
  const PurchaseList({Key? key}) : super(key: key);

  @override
  _PurchaseListState createState() => _PurchaseListState();
}

class _PurchaseListState extends State<PurchaseList> {
  List<PurchaseInfo> _purchases = [];

  Object segmentedControlGroupValue = 0;
  final _biggerFont = const TextStyle(fontSize: 18);

  @override
  void initState() {
    super.initState();
    getCurrentPurchases();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      backgroundColor: Colors.grey[200],
      appBar: AppBar(
        title: Text('AppMate Example'),
        actions: <Widget>[
          IconButton(
            icon: Icon(
              Icons.restore,
              color: Colors.white,
            ),
            onPressed: () {
              restorePurchases();
            },
          )
        ],
        centerTitle: false,
        backgroundColor: Colors.redAccent,
      ),
      body: SingleChildScrollView(child: _buildPurchases()),
    );
  }

  Future<void> getCurrentPurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.getCurrentPurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    if (!mounted) return;

    setState(() {
      _purchases = purchases;
    });
  }

  Future<void> getAllPurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.getAllPurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    if (!mounted) return;

    setState(() {
      _purchases = purchases;
    });
  }

  Future<void> restorePurchases() async {
    List<PurchaseInfo> purchases = [];
    try {
      PurchasesResponse response = await PurchaseClient.restorePurchases();
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        purchases = response.purchases ?? [];
      }
    } on PlatformException {}

    print("restorePurchases");
    print(purchases);

    if (!mounted) return;

    if (segmentedControlGroupValue == 0) {
      getCurrentPurchases();
    }
  }

  Future<void> consumePurchase(PurchaseInfo p) async {
    BaseResponse response;
    try {
      response = await PurchaseClient.consumePurchase(p.purchaseToken!);
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        Util.showDialog(
            context, response.success ? "Consume Success" : "Unknown Error");
        getCurrentPurchases();
      }
    } on PlatformException {}

    if (!mounted) return;
  }

  Future<void> unsubscribe(PurchaseInfo p) async {
    BaseResponse response;
    try {
      response = await PurchaseClient.unsubscribe(p.purchaseToken!);
      if (response.error != null) {
        Util.showDialog(context, response.error!.message ?? "Unknown Error");
      } else {
        Util.showDialog(context,
            response.success ? "Unsubscribe Success" : "Unknown Error");
        getAllPurchases();
      }
    } on PlatformException {}

    if (!mounted) return;
  }

  Widget _buildPurchases() {
    return Column(
      children: [
        Padding(
          padding: const EdgeInsets.only(top: 16),
          child: CupertinoSlidingSegmentedControl(
              groupValue: segmentedControlGroupValue,
              children: {
                0: Text("Current Purchases"),
                1: Text("Purchase History")
              },
              onValueChanged: (i) {
                setState(() {
                  segmentedControlGroupValue = i!;
                  if (segmentedControlGroupValue == 0) {
                    getCurrentPurchases();
                  } else if (segmentedControlGroupValue == 1) {
                    getAllPurchases();
                  }
                });
              }),
        ),
        ListView.builder(
            itemCount: _purchases.length * 2,
            padding: const EdgeInsets.all(5),
            shrinkWrap: true,
            physics: NeverScrollableScrollPhysics(),
            itemBuilder: (BuildContext _context, int i) {
              if (i.isOdd) {
                return Divider();
              }
              final int index = i ~/ 2;
              if (index >= _purchases.length) {
                return Divider();
              }
              return _buildRow(_purchases[index]);
            })
      ],
    );
  }

  String getProductType(String purchaseType) {
    if (purchaseType == "0") {
      return "Consumable";
    } else if (purchaseType == "1") {
      return "Nonsoncumable";
    } else if (purchaseType == "2") {
      return "Subscription";
    }
    return "";
  }

  Widget _buildRow(PurchaseInfo p) {
    return ListTile(
      title: Text(
        "token : " +
            p.purchaseToken! +
            "\nprice : " +
            (double.parse(p.price!) / 100).toStringAsFixed(2) +
            ' ' +
            p.currency!,
        style: _biggerFont,
      ),
      subtitle: Text("productId        : " +
          p.productId! +
          "\npurchaseType : " +
          getProductType(p.purchaseType!) +
          "\norderId            : " +
          p.orderId! +
          "\npurchaseTime : " +
          p.purchaseTime! +
          "\nconsumed       : " +
          p.consumed!.toString()),
      trailing: getTrailingIcon(p),
      onTap: () {},
    );
  }

  Widget? getTrailingIcon(PurchaseInfo p) {
    if (segmentedControlGroupValue == 0 && p.purchaseType == "0") {
      return IconButton(
        icon: Icon(
          Icons.payment,
          color: Colors.redAccent,
        ),
        onPressed: () {
          consumePurchase(p);
        },
      );
    } else if (segmentedControlGroupValue == 1 && p.purchaseType == "2") {
      return IconButton(
        icon: Icon(
          Icons.cancel,
          color: Colors.redAccent,
        ),
        onPressed: () {
          unsubscribe(p);
        },
      );
    }
    return null;
  }
}
